@@ -1,10 +1,16 @@
 #' @export
-group_by_.tbl_svy <- function(.data, ..., .dots, add = FALSE) {
-  .data$variables <- group_by_(.data$variables, ..., .dots = .dots, add = add)
+group_by.tbl_svy <- function(.data, ..., add = FALSE) {
+  .data$variables <- group_by(.data$variables, ..., add = add)
   class(.data) <- c("grouped_svy", class(.data))
   .data
 }
 
+#' @export
+group_by_.tbl_svy <- function(.data, ..., .dots, add = FALSE) {
+  dots <- compat_lazy_dots(.dots, caller_env(), ...)
+  group_by(.data, !!!dots, add = add)
+}
+
 #' @export
 ungroup.tbl_svy <- function(x, ...) {
   x
@@ -22,6 +28,10 @@ groups.tbl_svy <- function(x) {
   groups(x$variables)
 }
 
+#' @export
+group_vars.tbl_svy <- function(x) {
+  group_vars(x$variables)
+}
 
 
 #' Group a (survey) dataset by one or more variables.
@@ -86,3 +96,9 @@ NULL
 #' @export
 #' @importFrom dplyr ungroup
 NULL
+
+#' @rdname groups
+#' @name group_vars
+#' @export
+#' @importFrom dplyr group_vars
+NULL
